{ config, pkgs, ... }:

let
  gitpkgs = import <gitpkgs> {};

in {
  nixpkgs.config = {
    allowBroken = false;

    packageOverrides = pkgs: rec {
      goPackages = pkgs.go16Packages;
      bluez = pkgs.bluez5;
      linuxPackages = pkgs.linuxPackages_latest;
    };

    allowUnfree = true;

    chromium = {
      enablePepperFlash = true;
      enablePepperPDF = true;
    };

    firefox = {
      enableGoogleTalkPlugin = true;
      enableAdobeFlash = false;
    };

    pidgin = {
      openssl = true;
      gnutls = true;
    };

# TODO: implement support for this
#    libvirt = {
#      xenSupport = false;
#    };

  };

  imports =
    [
      ../common/pkg/default.nix
      (import ../common/pkg/neovim.nix { inherit config; pkgs = gitpkgs; })
    ];


  environment.systemPackages = with pkgs; [
    androidsdk_4_4

    nixops
    ansible 

    gnupg
    picocom
    xfce.terminal
    xorg.xbacklight
    coreutils
    lsof

    xscreensaver
    firefox-wrapper
    chromium

    qpdfview
    thunderbird
    pidgin
    hexchat
    skype

    x2goclient
    remmina
    teamviewer
    gnome3.dconf # needed by virtmanager
    virtmanager
    x11_ssh_askpass

    spotify
    vlc
    audacity
    pavucontrol
    
    gimp
    inkscape
    pdftk
    imagemagick

    iptables
    nftables
    iperf

    pandoc
    pythonFull
  ] ++ [
    gitpkgs.rkt
  ];

}
